function [f,g,h]= RLC_Circuit(xu,xl,k)
if nargin == 0
    prob.name = mfilename;
    prob.Upper_opt = 0.5003;
    prob.Lower_opt = 5.7637;
	prob.nxu = 3;
    prob.nxl = 2;
	prob.nf = 1; %upper level
    prob.nfl= 1; %lower level
	prob.ng = 0; %upper level
    prob.ngl= 0; %lower level
    %% UL Bounds
    prob.rangexu(1,:) = [500,1000];
    prob.rangexu(2,:) = [0.5,1];
    prob.rangexu(3,:) = [3.8*1e-6,4.2*1e-6];
    %% LL Bounds 
    prob.rangexl(1,:) = [600,1500]; % range of time values
    prob.rangexl(2,:) = [0.4,1.5];
    f = prob;
else
   if k == 1
    	[f,g,h] = RLC_Circuit_true_ul(xu,xl);
   elseif k==2
        [f,g,h] = RLC_Circuit_true_ll(xu,xl);
   else
        error('k can only be either 1(ul) or 2(ll)')
    end
end
return


function [f,g,h] = RLC_Circuit_true_ul(xu,xl)
    s = 850i;    
    f_tmp = xl(1)./((xl(1)+xl(2)*s)+(xu(1)+xu(2)*s)*(1+xu(3)*s*(xl(1)+xl(2)*s)));   
    f_ul =sqrt(real(f_tmp)^2 + imag(f_tmp)^2);    
    f = -f_ul;
    g = 0;
    h = 0;
return

function [f,g,h]= RLC_Circuit_true_ll(xu,xl)
    P1 = -500+1041i;
    P2 = -538+714i;    
    zeta_1 = xu(1)/(2*xu(2));     
    zeta_2 = xl(1)/(2*xl(2));
        
    a = xu(2)*xu(3)*xl(2); b = (xu(2)*xu(3)*xl(1) + xu(1)*xu(3)*xl(2)); c = (xu(2)+xl(2)+xu(1)*xu(3)*xl(1)); d = (xu(1)+xl(1));
    P = [a b c d];    
    roots_x_y = roots(P);    
    %% Scenario 1
    if min(abs(roots_x_y - P1)) <= min(abs(roots_x_y - P2)) 
      f_l = (min(abs(roots_x_y - P1))/zeta_1) + (1/imag(P1));
    %% Scenario 2  
    elseif min(abs(roots_x_y - P1)) > min(abs(roots_x_y - P2)) 
        f_l = (min(abs(roots_x_y - P2))/zeta_2) + (6000/imag(P1));
    end
    f = f_l;
    g = 0;
    h = 0;
return 